summary refs log tree commit diff
diff options
context:
space:
mode:
authorPatrick Cloke <patrickc@matrix.org>2023-07-18 11:41:57 -0400
committerPatrick Cloke <patrickc@matrix.org>2023-07-18 11:56:16 -0400
commit98c864bd464dd678bae7a281c87b5779fb428560 (patch)
treecb0e8ee75aaa678337383447395bb6d4f8ddbfaf
parentFix accepting an invite. (diff)
downloadsynapse-98c864bd464dd678bae7a281c87b5779fb428560.tar.xz
Do not return depth.
-rw-r--r--synapse/events/__init__.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/synapse/events/__init__.py b/synapse/events/__init__.py
index e06bba7afb..f95ec7dad7 100644
--- a/synapse/events/__init__.py
+++ b/synapse/events/__init__.py
@@ -627,7 +627,10 @@ class FrozenLinearizedEvent(FrozenEventV3):
     def get_pdu_json(self, time_now: Optional[int] = None) -> JsonDict:
         pdu = super().get_pdu_json()
 
-        # Internally Synapse uses unsigned, but this isn't part of LM.
+        # TODO(LM) Why does this sometimes exist?
+        pdu.pop("depth", None)
+
+        # Internally Synapse uses depth & unsigned, but this isn't part of LM.
         pdu.pop("unsigned")
 
         return pdu